@@ -6,8 +6,8 @@ from typing import Iterable
 
 from pdm.cli.actions import resolve_candidates_from_lockfile
 from pdm.cli.commands.base import BaseCommand
+from pdm.cli.filters import GroupSelection
 from pdm.cli.options import groups_group, lockfile_option
-from pdm.cli.utils import translate_groups
 from pdm.exceptions import PdmUsageError
 from pdm.formats import FORMATS
 from pdm.models.candidates import Candidate
@@ -45,25 +45,20 @@ class Command(BaseCommand):
             action="store_true",
             help="Read the list of packages from pyproject.toml",
         )
+        parser.add_argument("--expandvars", action="store_true", help="Expand environment variables in requirements")
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
-        groups: list[str] = list(options.groups)
         if options.pyproject:
             options.hashes = False
-        groups = translate_groups(
-            project,
-            options.default,
-            options.dev,
-            options.groups or (),
-        )
+        selection = GroupSelection.from_options(project, options)
         requirements: dict[str, Requirement] = {}
         packages: Iterable[Requirement] | Iterable[Candidate]
-        for group in groups:
+        for group in selection:
             requirements.update(project.get_dependencies(group))
         if options.pyproject:
             packages = requirements.values()
         else:
-            if not project.lockfile.exists:
+            if not project.lockfile.exists():
                 raise PdmUsageError("No lockfile found, please run `pdm lock` first.")
             project.core.ui.echo(
                 "The exported requirements file is no longer cross-platform. "
@@ -78,6 +73,6 @@ class Command(BaseCommand):
 
         content = FORMATS[options.format].export(project, packages, options)
         if options.output:
-            Path(options.output).write_text(content)
+            Path(options.output).write_text(content, encoding="utf-8")
         else:
-            project.core.ui.echo(content)
+            project.core.ui.echo(content, markup=False)
