@@ -37,6 +37,7 @@ from pdm.models.requirements import (
     strip_extras,
 )
 from pdm.models.specifiers import PySpecSet, get_specifier
+from pdm.project.lockfile import FLAG_CROSS_PLATFORM, FLAG_STATIC_URLS
 from pdm.utils import (
     comparable_version,
     is_path_relative_to,
@@ -514,9 +515,8 @@ def format_lockfile(
     project: Project,
     mapping: dict[str, Candidate],
     fetched_dependencies: dict[tuple[str, str | None], list[Requirement]],
-    groups: list[str] | None = None,
-    cross_platform: bool | None = None,
-    static_urls: bool | None = None,
+    groups: list[str] | None,
+    strategy: set[str],
 ) -> dict:
     """Format lock file from a dict of resolved candidates, a mapping of dependencies
     and a collection of package summaries.
@@ -544,7 +544,7 @@ def format_lockfile(
         if v.hashes:
             collected = {}
             for item in v.hashes:
-                if static_urls:
+                if FLAG_STATIC_URLS in strategy:
                     row = {"url": item["url"], "hash": item["hash"]}
                 else:
                     row = {"file": item["file"], "hash": item["hash"]}
@@ -561,10 +561,11 @@ def format_lockfile(
     metadata.update(
         {
             "groups": sorted(groups, key=lambda k: k != "default"),
-            "cross_platform": cross_platform if cross_platform is not None else project.lockfile.cross_platform,
-            "static_urls": static_urls if static_urls is not None else project.lockfile.static_urls,
+            "strategy": sorted(strategy),
         }
     )
+    metadata.pop(FLAG_STATIC_URLS, None)
+    metadata.pop(FLAG_CROSS_PLATFORM, None)
     doc.add("metadata", metadata)
     doc.add("package", packages)
     return cast(dict, doc)
