@@ -41,7 +41,15 @@ class CandidateInfoNotFound(PdmException):
         super().__init__(message)
 
 
-class ExtrasWarning(UserWarning):
+class PDMWarning(UserWarning):
+    pass
+
+
+class PackageWarning(PDMWarning):
+    pass
+
+
+class ExtrasWarning(PDMWarning):
     def __init__(self, project_name: str, extras: list[str]) -> None:
         super().__init__(f"Extras not found for {project_name}: [{','.join(extras)}]")
         self.extras = tuple(extras)
