@@ -1,13 +1,16 @@
 from __future__ import annotations
 
 import dataclasses
+import fnmatch
 import posixpath
+import re
 import sys
+import warnings
 from functools import wraps
-from typing import TYPE_CHECKING, TypeVar, cast
+from typing import TYPE_CHECKING, Generator, TypeVar, cast
 
 from pdm import termui
-from pdm.exceptions import CandidateInfoNotFound, CandidateNotFound
+from pdm.exceptions import CandidateInfoNotFound, CandidateNotFound, PackageWarning, PdmException
 from pdm.models.candidates import Candidate, make_candidate
 from pdm.models.requirements import (
     Requirement,
@@ -34,7 +37,6 @@ if TYPE_CHECKING:
 
     CandidateKey = tuple[str, str | None, str | None, bool]
 
-ALLOW_ALL_PYTHON = PySpecSet()
 T = TypeVar("T", bound="BaseRepository")
 
 
@@ -70,10 +72,26 @@ class BaseRepository:
         self.ignore_compatibility = ignore_compatibility
         self._candidate_info_cache = environment.project.make_candidate_info_cache()
         self._hash_cache = environment.project.make_hash_cache()
+        self.has_warnings = False
 
     def get_filtered_sources(self, req: Requirement) -> list[RepositoryConfig]:
         """Get matching sources based on the index attribute."""
-        return self.sources
+        source_preferences = [(s, self.source_preference(req, s)) for s in self.sources]
+        included_by = [s for s, p in source_preferences if p is True]
+        if included_by:
+            return included_by
+        return [s for s, p in source_preferences if p is None]
+
+    @staticmethod
+    def source_preference(req: Requirement, source: RepositoryConfig) -> bool | None:
+        key = req.key
+        if key is None:
+            return None
+        if any(fnmatch.fnmatch(key, pat) for pat in source.include_packages):
+            return True
+        if any(fnmatch.fnmatch(key, pat) for pat in source.exclude_packages):
+            return False
+        return None
 
     def get_dependencies(self, candidate: Candidate) -> tuple[list[Requirement], PySpecSet, str]:
         """Get (dependencies, python_specifier, summary) of the candidate."""
@@ -114,7 +132,7 @@ class BaseRepository:
             reqs = [req for req in reqs if not req.marker or req.marker.evaluate(pep508_env)]
         return reqs, PySpecSet(requires_python), summary
 
-    def _find_candidates(self, requirement: Requirement) -> Iterable[Candidate]:
+    def _find_candidates(self, requirement: Requirement, minimal_version: bool) -> Iterable[Candidate]:
         raise NotImplementedError
 
     def is_this_package(self, requirement: Requirement) -> bool:
@@ -135,14 +153,30 @@ class BaseRepository:
         candidate.prepare(self.environment).metadata
         return candidate
 
+    def _should_ignore_package_warning(self, requirement: Requirement) -> bool:
+        ignore_settings = self.environment.project.pyproject.settings.get("ignore_package_warnings", [])
+        package_name = requirement.key
+        assert package_name is not None
+        for pat in ignore_settings:
+            pat = re.sub(r"[^A-Za-z0-9?*\[\]]+", "-", pat).lower()
+            if fnmatch.fnmatch(package_name, pat):
+                return True
+        return False
+
     def find_candidates(
         self,
         requirement: Requirement,
         allow_prereleases: bool | None = None,
         ignore_requires_python: bool = False,
+        minimal_version: bool = False,
     ) -> Iterable[Candidate]:
         """Find candidates of the given NamedRequirement. Let it to be implemented in
         subclasses.
+
+        :param requirement: the requirement to find
+        :param allow_prereleases: whether to include pre-releases
+        :param ignore_requires_python: whether to ignore the requires-python marker
+        :param minimal_version: whether to prefer the minimal versions of the package
         """
         # `allow_prereleases` is None means leave it to specifier to decide whether to
         # include prereleases
@@ -151,16 +185,44 @@ class BaseRepository:
         if self.is_this_package(requirement):
             return [self.make_this_candidate(requirement)]
         requires_python = requirement.requires_python & self.environment.python_requires
-        cans = LazySequence(self._find_candidates(requirement))
+        cans = LazySequence(self._find_candidates(requirement, minimal_version=minimal_version))
         applicable_cans = LazySequence(
             c
             for c in cans
             if requirement.specifier.contains(c.version, allow_prereleases)  # type: ignore[arg-type, union-attr]
         )
 
-        applicable_cans_python_compatible = LazySequence(
-            c for c in applicable_cans if ignore_requires_python or requires_python.is_subset(c.requires_python)
-        )
+        def filter_candidates_with_requires_python(candidates: Iterable[Candidate]) -> Generator[Candidate, None, None]:
+            project_requires_python = self.environment.python_requires
+            if ignore_requires_python:
+                yield from candidates
+                return
+
+            def python_specifier(spec: str | PySpecSet) -> str:
+                if isinstance(spec, PySpecSet):
+                    spec = str(spec)
+                return "all Python versions" if not spec else f"Python{spec}"
+
+            for candidate in candidates:
+                if not requires_python.is_subset(candidate.requires_python):
+                    if self._should_ignore_package_warning(requirement):
+                        continue
+                    working_requires_python = project_requires_python & PySpecSet(candidate.requires_python)
+                    if working_requires_python.is_impossible:  # pragma: no cover
+                        continue
+                    warnings.warn(
+                        f"Skipping {candidate.name}@{candidate.version} because it requires "
+                        f"{python_specifier(candidate.requires_python)} but the project claims to work with "
+                        f"{python_specifier(project_requires_python)}.\nNarrow down the `requires-python` range to "
+                        f'include this version. For example, "{working_requires_python}" should work.',
+                        PackageWarning,
+                        stacklevel=4,
+                    )
+                    self.has_warnings = True
+                else:
+                    yield candidate
+
+        applicable_cans_python_compatible = LazySequence(filter_candidates_with_requires_python(applicable_cans))
         # Evaluate data-requires-python attr and discard incompatible candidates
         # to reduce the number of candidates to resolve.
         if applicable_cans_python_compatible:
@@ -174,9 +236,7 @@ class BaseRepository:
             applicable_cans = LazySequence(
                 c for c in cans if requirement.specifier.contains(c.version, True)  # type: ignore[arg-type, union-attr]
             )
-            applicable_cans_python_compatible = LazySequence(
-                c for c in applicable_cans if ignore_requires_python or requires_python.is_subset(c.requires_python)
-            )
+            applicable_cans_python_compatible = LazySequence(filter_candidates_with_requires_python(applicable_cans))
             if applicable_cans_python_compatible:
                 applicable_cans = applicable_cans_python_compatible
 
@@ -296,10 +356,10 @@ class BaseRepository:
         respect_source_order = self.environment.project.pyproject.settings.get("resolution", {}).get(
             "respect-source-order", False
         )
+        sources = self.get_filtered_sources(candidate.req)
         if req.is_named and respect_source_order and comes_from:
-            sources = [s for s in self.sources if comes_from.startswith(s.url)]
-        else:
-            sources = self.sources
+            sources = [s for s in sources if comes_from.startswith(s.url)]
+
         with self.environment.get_finder(sources, self.ignore_compatibility) as finder:
             if req.is_file_or_url:
                 this_link = cast("Link", candidate.prepare(self.environment).link)
@@ -386,11 +446,11 @@ class PyPIRepository(BaseRepository):
             yield self._get_dependencies_from_json
         yield self._get_dependencies_from_metadata
 
-    def _find_candidates(self, requirement: Requirement) -> Iterable[Candidate]:
+    def _find_candidates(self, requirement: Requirement, minimal_version: bool) -> Iterable[Candidate]:
         from unearth.utils import LazySequence
 
         sources = self.get_filtered_sources(requirement)
-        with self.environment.get_finder(sources, self.ignore_compatibility) as finder:
+        with self.environment.get_finder(sources, self.ignore_compatibility, minimal_version=minimal_version) as finder:
             cans = LazySequence(
                 Candidate.from_installation_candidate(c, requirement)
                 for c in finder.find_all_packages(requirement.project_name, allow_yanked=requirement.is_pinned)
@@ -445,7 +505,10 @@ class LockedRepository(BaseRepository):
         return {can.req.identify(): can for can in self.packages.values()}
 
     def _read_lockfile(self, lockfile: Mapping[str, Any]) -> None:
+        from pdm.project.lockfile import FLAG_STATIC_URLS
+
         root = self.environment.project.root
+        static_urls = FLAG_STATIC_URLS in self.environment.project.lockfile.strategy
         with cd(root):
             for package in lockfile.get("package", []):
                 version = package.get("version")
@@ -460,6 +523,10 @@ class LockedRepository(BaseRepository):
                     req.url = path_to_url(posixpath.join(root, req.path))  # type: ignore[attr-defined]
                 can = make_candidate(req, name=package_name, version=version)
                 can.hashes = package.get("files", [])
+                if not static_urls and any("url" in f for f in can.hashes):
+                    raise PdmException(
+                        "Static URLs are not allowed in lockfile unless enabled by `pdm lock --static-urls`."
+                    )
                 can_id = self._identify_candidate(can)
                 self.packages[can_id] = can
                 candidate_info: CandidateInfo = (
@@ -518,6 +585,7 @@ class LockedRepository(BaseRepository):
         requirement: Requirement,
         allow_prereleases: bool | None = None,
         ignore_requires_python: bool = False,
+        minimal_version: bool = False,
     ) -> Iterable[Candidate]:
         if self.is_this_package(requirement):
             candidate = self.make_this_candidate(requirement)
