@@ -16,6 +16,7 @@ import sysconfig
 import tempfile
 import urllib.parse as parse
 import warnings
+from os import name as os_name
 from pathlib import Path
 from typing import TYPE_CHECKING
 
@@ -41,7 +42,7 @@ PACKAGING_22 = Version(_packaging_version) >= Version("22")
 
 
 def create_tracked_tempdir(suffix: str | None = None, prefix: str | None = None, dir: str | None = None) -> str:
-    name = tempfile.mkdtemp(suffix, prefix, dir)
+    name = tempfile.mkdtemp(suffix=suffix, prefix=prefix, dir=dir)
     os.makedirs(name, mode=0o777, exist_ok=True)
 
     def clean_up() -> None:
@@ -75,21 +76,16 @@ def join_list_with(items: list[Any], sep: Any) -> list[Any]:
     return new_items[:-1]
 
 
-def find_project_root(cwd: str = ".", max_depth: int = 5) -> str | None:
-    """Recursively find a `pyproject.toml` at given path or current working directory.
-    If none if found, go to the parent directory, at most `max_depth` levels will be
-    looked for.
-    """
-    original_path = Path(cwd).absolute()
-    path = original_path
-    for _ in range(max_depth):
-        if path.joinpath("pyproject.toml").exists():
-            return path.as_posix()
-        if path.parent == path:
-            # Root path is reached
-            break
-        path = path.parent
-    return None
+def find_project_root(cwd: str = ".") -> str | None:
+    """Recursively find a `pyproject.toml` at given path or current working directory."""
+    path = Path(cwd).absolute()
+    if list(path.glob("pyproject.toml")):
+        return path.as_posix()
+
+    if path == path.parent:
+        return None
+
+    return find_project_root(str(path.parent))
 
 
 def convert_hashes(files: list[FileHash]) -> dict[str, list[str]]:
@@ -259,7 +255,7 @@ def path_replace(pattern: str, replace_with: str, dest: str) -> str:
     :param dest: the path to replace
     :return the replaced path
     """
-    sub_flags = re.IGNORECASE if os.name == "nt" else 0
+    sub_flags = re.IGNORECASE if os_name == "nt" else 0
     return re.sub(
         pattern.replace("\\", "/"),
         replace_with,
